@@ -83,6 +83,9 @@ dataUrl = "http://ilthermo.boulder.nist.gov/ILT2/ilset"
 
 
 def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
+    #JOAO
+    global prp
+    #JOAO
     """ Starts a query on the Ionic Liquids Database from NIST.
 
     Each web form field is represented by a keyword argument.
@@ -107,23 +110,11 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     """
     if prop:
         if prop not in abr2prop.keys():
-            ##JOAO
-            print("prop not in abr2prop.keys")
-            ##JOAO
             raise propertyError(prop)
         else:
-            ##JOAO
-            propr = properties[prop][0]
-            print("propr: ",propr)
-            ##JOAO
+            # prp = properties[prop][0]
             prp = abr2key[prop]
-            ##JOAO
-            print("prp: ",prp)
-            ##JOAO
     else:
-        ##JOAO
-        print("deu else no prop do modem do badjora")
-        ##JOAO
         prp = ''
     params = dict(
         cmp = comp,
@@ -136,13 +127,7 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     r = requests.get(searchUrl, params=params)
     resDict = r.json()
     if len(resDict['errors']) > 0:
-        ##JOAO
-        print("deu petara do modem do badjora")
-        ##JOAO
         e = " *** ".join(resDict['errors'])
-        ##JOAO
-        print("deu erro:", e)
-        ##JOAO
         raise queryError(e)
     return result(resDict)
 
