@@ -263,12 +263,17 @@ def cliQuery(comp='', numOfComp=0, year='', author='', keywords='', prop='', ver
                               author=author,
                               keywords=keywords,
                               prop=prop)
+        #JOAO
+        print("prp: ",prp)
+        #JOAO
     except:
         if verbose:
             spinner.stop()
         e = sys.exc_info()[1]
         print('Error: {0:s}'.format(str(e)))
-        exit(1)
+        #JOAO
+        #exit(1)
+        #JOAO
     else:
         if verbose:
             spinner.stop()
